//----------------------------------------------------------------------
//
//  FILE:   BenchmarkPlot.hh
//  AUTHOR: Ian Ross
//  DATE:   28-MAR-2005
//
//----------------------------------------------------------------------
//
//  Base class for MOTIF benchmark plot generation classes.
//
//----------------------------------------------------------------------

#ifndef _H_BENCHMARK_PLOT_
#define _H_BENCHMARK_PLOT_

//----------------------------------------------------------------------
//
//  HEADER FILES
//

// Standard headers.

#include <string>
#include <vector>

using namespace std;


// Local headers.

#include "simple_types.hh"
#include "PlotSetup.hh"


//----------------------------------------------------------------------
//
//  CLASS DEFINITION
//

class BenchmarkPlot {
public:

  // This class is an abstract base from which concrete classes for
  // different kinds of plot are derived.

  virtual ~BenchmarkPlot() { }
  virtual void plot(void) = 0;


  // Accessors.
  string variable(void) const { return _var_name; }
  const PlotSetup &setup(void) const { return _setup; }
  bool valid(void) const { return _valid; }
  string eps_file(void) const { return _eps_file; }


protected:

  // Only created via derived classes.

  BenchmarkPlot(string model, Domain domain, string var_name,
                string var_full_name, OutputFreq freq,
                const PlotSetup &setup);


  string data_file(void) { return _data_file; }
  string date_mark(void);
  void set_valid(void) { _valid = true; }
  void map_plot(string real_data_file);
  virtual void zonally_averaged_plot(string real_data_file) { }

  string get_data_file(Domain domain, string var_name);

  virtual void colours(FILE *fp, int &grid_colour) { grid_colour = 0; }
  virtual string title_string(void) { return ""; }
  virtual void scaling(float &scale_factor, float &offset, string &units)
  { scale_factor = 1.0;  offset = 0.0; }

  string _model;
  Domain _domain;
  string _var_name;
  string _var_full_name;
  OutputFreq _freq;
  PlotSetup _setup;

private:

  bool _valid;
  string _data_file;
  string _eps_file;
};

#endif

//----------------------------------------------------------------------
//----------------------------------------------------------------------
//----------------------------------------------------------------------
