//----------------------------------------------------------------------
//
//  FILE:   DBFile.hh
//  AUTHOR: Ian Ross
//  DATE:   28-MAR-2005
//
//----------------------------------------------------------------------
//
//  Class for handling MOTIF database files for benchmarking tools.
//
//----------------------------------------------------------------------

#ifndef _H_DB_FILE_
#define _H_DB_FILE_

//----------------------------------------------------------------------
//
//  HEADER FILES
//

// Standard headers.

#include <string>

using namespace std;


// Local headers.

#include "simple_types.hh"
#include "PlotSetup.hh"


//----------------------------------------------------------------------
//
//  CLASS DEFINITION
//

class DBFile {
public:

  DBFile(string model, Domain domain, string var_name,
         ModelRun run, OutputFreq freq);

  bool valid(void) const { return _valid; }
  bool multiple(void) const { return _multiple; }

  string full_path(void) const;

  void collapse_multiple(void);
  string generate_anomalies(DBFile &other);

private:

  void build_path_template(void);

  string _model;
  Domain _domain;
  string _var_name;
  ModelRun _run;
  OutputFreq _freq;

  bool _valid;
  bool _multiple;
  bool _collapsed;
  bool _constructed;
  string _collapsed_path;
  string _path_template;
  string _constructed_path_template;
};

#endif

//----------------------------------------------------------------------
//----------------------------------------------------------------------
//----------------------------------------------------------------------
