//----------------------------------------------------------------------
//
//  FILE:   PMinusEBenchmarkPlot.cpp
//  AUTHOR: Ian Ross
//  DATE:   28-MAR-2005
//
//----------------------------------------------------------------------
//
//  Class for MOTIF benchmark seasonal plot generation.
//
//----------------------------------------------------------------------

//----------------------------------------------------------------------
//
//  HEADER FILES
//

// Standard headers.

#include <cstdio>

using namespace std;


// Local headers.

#include "PMinusEBenchmarkPlot.hh"
#include "TempFile.hh"


//----------------------------------------------------------------------
//
//  MEMBER FUNCTION DEFINITIONS
//

PMinusEBenchmarkPlot::PMinusEBenchmarkPlot
(string model, const PlotSetup &setup) :
  BenchmarkPlot(model, ATMOS, "pr", "Precipitation Minus Evaporation",
                SEASONAL, setup)
{
  if (data_file() != "") {
    string evap_filename = get_data_file(ATMOS, "evspsbl");
    if (evap_filename == "")
      _plot_data_file = "";
    else {
      char buff[256];
      sprintf(buff, "ncra -d time,0,,1 %s ###", data_file().c_str());
      string precip_data_file = TempFile::get("nc", buff);
      cout << "Evap. file: " << evap_filename << endl;
      sprintf(buff, "ncra -d time,0,,1 %s ###", evap_filename.c_str());
      string evap_data_file = TempFile::get("nc", buff);
      sprintf(buff, "ncrename -v evspsbl,pr %s ###", evap_data_file.c_str());
      string evap_data_file2 = TempFile::get("nc", buff);
      sprintf(buff, "ncdiff %s %s ###",
              precip_data_file.c_str(), evap_data_file2.c_str());
      _plot_data_file = TempFile::get("nc", buff);
    }
  } else
    _plot_data_file = "";
}


void PMinusEBenchmarkPlot::plot(void)
{
  if (_plot_data_file == "") return;
  map_plot(_plot_data_file);
  set_valid();
}


void PMinusEBenchmarkPlot::colours(FILE *fp, int &grid_colour)
{
  grid_colour = 254;
  fprintf(fp, "gsn_define_colormap(wks, \"BlueRedGray\")\n");

  fprintf(fp, "levels = "
          "(/ -20,-18,-16,-14,-12,-10,-8,-6,-4,-2,-1,-0.5,-0.25,-0.01,"
          "0.01,0.25,0.5,1,2,4,6,8,10,12,14,16,18,20 /)\n");
  fprintf(fp, "fill_colours = "
          "(/ 253,243,234,224,215,205,195,186,176,166,157,147,138,128,0,"
          "127,117,108,98,89,79,69,60,50,40,31,21,12,2 /)\n");
  fprintf(fp, "res@lbLabelAngleF = 90.0\n");
}


void PMinusEBenchmarkPlot::scaling
(float &scale_factor, float &offset, string &units)
{
  // Input data is in kg m-2 s-1; plots should be in mm day-1.
  offset = 0.0;
  scale_factor = 3600 * 24;
  units = "mm/day";
}


string PMinusEBenchmarkPlot::title_string(void)
{
  char buff[256];
  sprintf(buff, "%s Annual Precipitation Minus Evaporation (%s)",
          _model.c_str(), string(_setup).c_str());
  return buff;
}


//----------------------------------------------------------------------
//----------------------------------------------------------------------
//----------------------------------------------------------------------
