//----------------------------------------------------------------------
//
//  FILE:   PlotSetup.hh
//  AUTHOR: Ian Ross
//  DATE:   28-MAR-2005
//
//----------------------------------------------------------------------
//
//  Basic plot setup definitions (i.e. which run or pair or runs for
//  anomaly plots) for MOTIF benchmarking tools.
//
//----------------------------------------------------------------------

#ifndef _H_PLOT_SETUP_
#define _H_PLOT_SETUP_

//----------------------------------------------------------------------
//
//  HEADER FILES
//

// Standard headers.

#include <iostream>

using namespace std;


// Local headers.

#include "simple_types.hh"


//----------------------------------------------------------------------
//
//  CLASS DEFINITION
//

class PlotSetup {
public:

  // Constructors for simple single plot and for anomaly plots.

  PlotSetup(ModelRun single) :
    _single(true), _run1(single), _run2(INVALID) { }
  PlotSetup(ModelRun expt, ModelRun ctrl) :
    _single(false), _run1(expt), _run2(ctrl) { }


  // Other structural methods.

  PlotSetup(const PlotSetup &other) :
    _single(other._single), _run1(other._run1), _run2(other._run2) { }
  const PlotSetup &operator=(const PlotSetup &other)
  {
    if (&other != this) {
      _single = other._single;
      _run1 = other._run1;
      _run2 = other._run2;
    }
    return *this;
  }


  // Accessors.

  bool single(void) const { return _single; }
  ModelRun run(void) const;
  ModelRun experiment(void) const;
  ModelRun control(void) const;

  bool operator==(const PlotSetup &other) {
    if (_single != other._single) return false;
    if (_single) return _run1 == other._run1;
    else return _run1 == other._run1 && _run2 == other._run2;
  }
  bool operator!=(const PlotSetup &other) { return !(*this == other); }

  operator string();

  static bool _vis_strings;


private:

  bool _single;
  ModelRun _run1, _run2;
};

ostream &operator<<(ostream &str, const PlotSetup &setup);


#endif

//----------------------------------------------------------------------
//----------------------------------------------------------------------
//----------------------------------------------------------------------
