//----------------------------------------------------------------------
//
//  FILE:   TempFile.cpp
//  AUTHOR: Ian Ross
//  DATE:   28-MAR-2005
//
//----------------------------------------------------------------------
//
//  Temporary file handling for MOTIF benchmark plot generation classes.
//
//----------------------------------------------------------------------

//----------------------------------------------------------------------
//
//  HEADER FILES
//

// Standard headers.

#include <iostream>
#include <sys/types.h>
#include <unistd.h>
#include <cstdio>
#include <string>
#include <vector>
#include <map>

using namespace std;

// Local headers.

#include "TempFile.hh"


//----------------------------------------------------------------------
//
//  GLOBAL VARIABLE DEFINITIONS
//

static vector<string> unnamed_temp; 
static map<string, string> named_temp;


//----------------------------------------------------------------------
//
//  MEMBER FUNCTION DEFINITIONS
//

static string temporary(string suffix)
{
  static int idx = 1;
  char buff[512];
  int pid = reinterpret_cast<int>(getpid());
  sprintf(buff, "tmp-%08X-%04d.%s", pid, idx, suffix.c_str());
  ++idx;
  return buff;
}


string TempFile::get(string suffix)
{
  string fname = temporary(suffix);
  unnamed_temp.push_back(fname);
  return fname;
}


string TempFile::get(string suffix, string command)
{
  if (named_temp.find(command) != named_temp.end())
    return named_temp[command];
  else {
    string fname = temporary(suffix);
    string buff = command;
    string::size_type pos = buff.find("###");
    if (pos == string::npos) throw "TempFile::get - no marker in command";
    buff.replace(pos, 3, fname);
    cout << buff << endl;
    system(buff.c_str());
    named_temp[command] = fname;
    return fname;
  }
}


void TempFile::clean(void)
{
  for (vector<string>::iterator it = unnamed_temp.begin();
       it != unnamed_temp.end(); ++it)
    unlink(it->c_str());
  unnamed_temp.clear();

  for (map<string,string>::iterator it = named_temp.begin();
       it != named_temp.end(); ++it)
    unlink(it->second.c_str());
  named_temp.clear();
}


//----------------------------------------------------------------------
//----------------------------------------------------------------------
//----------------------------------------------------------------------
