//----------------------------------------------------------------------
//
//  FILE:   ZonalPrecipData.cpp
//  AUTHOR: Ian Ross
//  DATE:   28-MAR-2005
//
//----------------------------------------------------------------------
//
//  Class for MOTIF benchmark seasonal plot generation.
//
//----------------------------------------------------------------------

//----------------------------------------------------------------------
//
//  HEADER FILES
//

// Standard headers.

#include <iostream>
#include <fstream>
#include <cstdio>
#include <netcdf.hh>

using namespace std;


// Local headers.

#include "ZonalPrecipData.hh"
#include "TempFile.hh"


//----------------------------------------------------------------------
//
//  MEMBER FUNCTION DEFINITIONS
//

ZonalPrecipData::ZonalPrecipData
(string model, const PlotSetup &setup) :
  BenchmarkPlot(model, ATMOS, "pr", "Total Precipitation", SEASONAL, setup)
{
  cout << setup << endl;
  if (data_file() != "") {
    char buff[256];
    sprintf(buff, "ncra -d time,0,,1 %s ###", data_file().c_str());
    _plot_data_file = TempFile::get("nc", buff);

    // Zonally average from 20W to 30E for each latitude.

    string tmp_file = _plot_data_file;
    sprintf(buff, "ncks -d lat,0.0,30.0 -d lon,-20.0,30.0 %s ###",
            tmp_file.c_str());
    tmp_file = TempFile::get("nc", buff);
    sprintf(buff, "ncwa -a lon %s ###", tmp_file.c_str());
    _plot_data_file = TempFile::get("nc", buff);
  } else
    _plot_data_file = "";
}


void ZonalPrecipData::plot(void)
{
  if (_plot_data_file == "") return;
  NcFile prfp(_plot_data_file.c_str());
  NcDim *lat_dim = prfp.get_dim("lat");
  float *lat = new float[lat_dim->size()], *pr = new float[lat_dim->size()];
  NcVar *lat_var = prfp.get_var("lat");
  NcVar *pr_var = prfp.get_var("pr");
  for (int idx = 0; idx < lat_dim->size(); ++idx) {
    lat[idx] = lat_var->as_float(idx);
    pr[idx] = pr_var->as_float(idx);
  }
  string s = string(_setup);
  string dat_file = _model + "_" + s + ".csv";
  ofstream outstr(dat_file.c_str());
  for (int idx = 0; idx < lat_dim->size(); ++idx)
    outstr << lat[idx] << ',' << pr[idx] * 3600 * 24 << '\r' << endl;
  outstr.close();
  delete [] lat;
  delete [] pr;
  set_valid();
}


//----------------------------------------------------------------------
//----------------------------------------------------------------------
//----------------------------------------------------------------------
